Bomcheck Help

# bomcheckgui help

- Introduction
- How to run bomcheck
- bomcheck_help.html
- Troubleshooting

## Introduction

The bomcheck program was originally written to be run from a Command Prompt Terminal (cmd.exe). The program bomcheckgui is actually a wrapper that presents a graphical user interface (gui) for the bomcheck program. That is, bomcheckgui runs the bomcheck program in the background. See bomcheck_help.html for info about how bomcheck works.

## How to run bomcheckgui:

Drag and drop the BOM files that you want to be checked onto the central portion of the gui. File names that do not end with _sw.xlsx or sl_xlsx will be ignored. Files that contain a tilde character, ~, will also be ignored.

Press the green check button icon to have your BOMs analyzed. To print results or save results to a csv file, click the boxes located at the bottom of the pop up window containing results. See how to open a csv file in Excel.

If you wish to check other BOM files, push the clear button to clear the list of files. Then drag and drop the new files you want checked.

If at some point in your work day you close the folder that contains your BOMs, and later you want to reopen it to make changes, instead of having to search for that folder again, click on the folder icon. The folder will open.

Tip 1: Instead of dragging individual file names into the bomcheckgui program, you can drag in the folder that contains the files that are to be checked. Then once the program is run, the program's action will be to do a bom check of the files in that folder. The advantage of doing it this way is that files in a Microsoft File Explorer window can be updated without having to clear previous selections and reinserting new files.

Tip 2: Save yourself some keystrokes: Instead of placing the multilevel BOM from SyteLine into the folder that contains the SolidWorks BOMs, copy the multilevel SyteLine BOM to the clipboard. Bomcheck will find that BOM in the clipboard and will use it for evaluation. (To copy to the clipboard, open up the SyteLine BOM in Excel, click the empty cell located to the left of the column header named "A", and then do a Ctrl-C.)